@@ -97,7 +97,8 @@ def create_non_dynamic_with_ff(
         m_a=variable_pool.outgoing_state_mass1,
         m_b=variable_pool.outgoing_state_mass2,
     )
-    meson_radius = sp.Symbol(f"d_{resonance.name}")
+    res_identifier = resonance.latex if resonance.latex else resonance.name
+    meson_radius = sp.Symbol(f"d_{{{res_identifier}}}")
     form_factor_squared = BlattWeisskopfSquared(
         angular_momentum,
         z=q_squared * meson_radius**2,
@@ -164,8 +165,9 @@ class RelativisticBreitWignerBuilder:
         resonance: Particle, variable_pool: TwoBodyKinematicVariableSet
     ) -> "BuilderReturnType":
         inv_mass = variable_pool.incoming_state_mass
-        res_mass = sp.Symbol(f"m_{resonance.name}")
-        res_width = sp.Symbol(f"Gamma_{resonance.name}")
+        res_identifier = resonance.latex if resonance.latex else resonance.name
+        res_mass = sp.Symbol(f"m_{{{res_identifier}}}")
+        res_width = sp.Symbol(Rf"\Gamma_{{{res_identifier}}}")
         expression = relativistic_breit_wigner(
             s=inv_mass**2,
             mass0=res_mass,
@@ -246,9 +248,10 @@ class RelativisticBreitWignerBuilder:
     def __create_symbols(
         resonance: Particle,
     ) -> Tuple[sp.Symbol, sp.Symbol, sp.Symbol]:
-        res_mass = sp.Symbol(f"m_{resonance.name}")
-        res_width = sp.Symbol(f"Gamma_{resonance.name}")
-        meson_radius = sp.Symbol(f"d_{resonance.name}")
+        res_identifier = resonance.latex if resonance.latex else resonance.name
+        res_mass = sp.Symbol(f"m_{{{res_identifier}}}")
+        res_width = sp.Symbol(Rf"\Gamma_{{{res_identifier}}}")
+        meson_radius = sp.Symbol(f"d_{{{res_identifier}}}")
         return res_mass, res_width, meson_radius
 
 
