@@ -44,8 +44,8 @@ class TestRelativisticBreitWignerBuilder:
         builder.form_factor = False
         bw, parameters = builder(particle, variable_set)
         s = variable_set.incoming_state_mass**2
-        m0 = sp.Symbol("m_N")
-        w0 = sp.Symbol("Gamma_N")
+        m0 = sp.Symbol("m_{N}")
+        w0 = sp.Symbol(R"\Gamma_{N}")
         assert bw == w0 * m0 / (-sp.I * w0 * m0 - s + m0**2)
         assert set(parameters) == {m0, w0}
         assert parameters[m0] == particle.mass
@@ -57,7 +57,7 @@ class TestRelativisticBreitWignerBuilder:
         m2 = variable_set.outgoing_state_mass2
         q_squared = BreakupMomentumSquared(s, m1, m2)
         L = variable_set.angular_momentum  # noqa: N806
-        d = sp.Symbol("d_N")
+        d = sp.Symbol(R"d_{N}")
         ff = sp.sqrt(BlattWeisskopfSquared(L, d**2 * q_squared))
         assert bw_with_ff / bw == ff
         assert set(parameters) == {m0, w0, d}
@@ -73,12 +73,12 @@ class TestRelativisticBreitWignerBuilder:
         builder.form_factor = False
         bw, parameters = builder(particle, variable_set)
         s = variable_set.incoming_state_mass**2
-        m0 = sp.Symbol("m_N")
-        w0 = sp.Symbol("Gamma_N")
+        m0 = sp.Symbol("m_{N}")
+        w0 = sp.Symbol(R"\Gamma_{N}")
         m1 = variable_set.outgoing_state_mass1
         m2 = variable_set.outgoing_state_mass2
         L = variable_set.angular_momentum  # noqa: N806
-        d = sp.Symbol("d_N")
+        d = sp.Symbol(R"d_{N}")
         w = EnergyDependentWidth(
             s, m0, w0, m_a=m1, m_b=m2, angular_momentum=L, meson_radius=d
         )
